@@ -2,6 +2,7 @@ from typing import Any, List, Mapping, TYPE_CHECKING, Tuple, Type, Union
 
 import databases
 import sqlalchemy
+from sqlalchemy import bindparam
 
 import ormar  # noqa I100
 from ormar import MultipleMatches, NoMatch
@@ -247,3 +248,49 @@ class QuerySet:
         if pk and isinstance(pk, self.model_cls.pk_type()):
             setattr(instance, self.model_cls.Meta.pkname, pk)
         return instance
+
+    async def bulk_create(self, objects: List["Model"]) -> None:
+        ready_objects = []
+        for objt in objects:
+            new_kwargs = objt.dict()
+            new_kwargs = self._remove_pk_from_kwargs(new_kwargs)
+            new_kwargs = self.model_cls.substitute_models_with_pks(new_kwargs)
+            new_kwargs = self._populate_default_values(new_kwargs)
+            ready_objects.append(new_kwargs)
+
+        expr = self.table.insert()
+        await self.database.execute_many(expr, ready_objects)
+
+    async def bulk_update(
+        self, objects: List["Model"], columns: List[str] = None
+    ) -> None:
+        ready_objects = []
+        pk_name = self.model_cls.Meta.pkname
+        if not columns:
+            columns = self.model_cls.extract_db_own_fields().union(
+                self.model_cls.extract_related_names()
+            )
+
+        if pk_name not in columns:
+            columns.append(pk_name)
+
+        for objt in objects:
+            new_kwargs = objt.dict()
+            if pk_name not in new_kwargs or new_kwargs.get(pk_name) is None:
+                raise QueryDefinitionError(
+                    "You cannot update unsaved objects. "
+                    f"{self.model_cls.__name__} has to have {pk_name} filled."
+                )
+            new_kwargs = self.model_cls.substitute_models_with_pks(new_kwargs)
+            new_kwargs = {"new_" + k: v for k, v in new_kwargs.items() if k in columns}
+            ready_objects.append(new_kwargs)
+
+        pk_column = self.model_cls.Meta.table.c.get(pk_name)
+        expr = self.table.update().where(pk_column == bindparam("new_" + pk_name))
+        expr = expr.values(
+            **{k: bindparam("new_" + k) for k in columns if k != pk_name}
+        )
+        # databases bind params only where query is passed as string
+        # otherwise it just pases all data to values and results in unconsumed columns
+        expr = str(expr)
+        await self.database.execute_many(expr, ready_objects)
